@@ -732,7 +732,7 @@ class xmlDoc():
                                                     xmlNewArea)[0]
                     oldAreaCaption = xpath.Evaluate('child::caption',
                                                     oldAreaNode)[0]
-                    if newAreaCaption and oldAreaCaption:
+                    if newAreaCaption is not None and oldAreaCaption is not None:
                         #its was "replace(old, new)" in legacy code, even though
                         #the func takes (new, old). Mistake, or on purpose?
                         #xmlNewArea.replaceChild(oldAreaCaption, newAreaCaption)
